==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/BodyInComponentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodyInComponent;
import io.ciera.tool.sql.ooaofooa.body.BodyInComponentSet;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_CSetImpl;

import java.util.Arrays;
import java.util.List;


public class BodyInComponentSetImpl extends InstanceSet<BodyInComponentSet,BodyInComponent> implements BodyInComponentSet {

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( BodyInComponent bodyincomponent : this ) bodyincomponent.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setComponent_Id( UniqueId ref_Component_Id ) throws XtumlException {
        for ( BodyInComponent bodyincomponent : this ) bodyincomponent.setComponent_Id( ref_Component_Id );
    }


    // selections
    @Override
    public BodySet R694_has_declared_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( BodyInComponent bodyincomponent : this ) bodyset.add( bodyincomponent.R694_has_declared_Body() );
        return bodyset;
    }
    @Override
    public C_CSet R694_is_declared_in_C_C() throws XtumlException {
        C_CSet c_cset = new C_CSetImpl();
        for ( BodyInComponent bodyincomponent : this ) c_cset.add( bodyincomponent.R694_is_declared_in_C_C() );
        return c_cset;
    }


    @Override
    public BodyInComponent nullElement() {
        return BodyInComponentImpl.EMPTY_BODYINCOMPONENT;
    }

    @Override
    public BodyInComponentSet emptySet() {
      return new BodyInComponentSetImpl();
    }

    @Override
    public BodyInComponentSet value() {
        return this;
    }

    @Override
    public List<BodyInComponent> elements() {
        return Arrays.asList(toArray(new BodyInComponent[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/BodyInComponentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodyInComponent;
import io.ciera.tool.sql.ooaofooa.body.BodyInComponentSet;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_CSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class BodyInComponentSetImpl extends InstanceSet<BodyInComponentSet,BodyInComponent> implements BodyInComponentSet {

    public BodyInComponentSetImpl() {
    }

    public BodyInComponentSetImpl(Comparator<? super BodyInComponent> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setComponent_Id( UniqueId ref_Component_Id ) throws XtumlException {
        for ( BodyInComponent bodyincomponent : this ) bodyincomponent.setComponent_Id( ref_Component_Id );
    }
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( BodyInComponent bodyincomponent : this ) bodyincomponent.setAction_ID( ref_Action_ID );
    }


    // selections
    @Override
    public BodySet R694_has_declared_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( BodyInComponent bodyincomponent : this ) bodyset.add( bodyincomponent.R694_has_declared_Body() );
        return bodyset;
    }
    @Override
    public C_CSet R694_is_declared_in_C_C() throws XtumlException {
        C_CSet c_cset = new C_CSetImpl();
        for ( BodyInComponent bodyincomponent : this ) c_cset.add( bodyincomponent.R694_is_declared_in_C_C() );
        return c_cset;
    }


    @Override
    public BodyInComponent nullElement() {
        return BodyInComponentImpl.EMPTY_BODYINCOMPONENT;
    }

    @Override
    public BodyInComponentSet emptySet() {
      return new BodyInComponentSetImpl();
    }

    @Override
    public BodyInComponentSet emptySet(Comparator<? super BodyInComponent> comp) {
      return new BodyInComponentSetImpl(comp);
    }

    @Override
    public BodyInComponentSet value() {
        return this;
    }

    @Override
    public List<BodyInComponent> elements() {
        return Arrays.asList(toArray(new BodyInComponent[0]));
    }

}
